===================================
 ``django_celery_monitor.models``
===================================

.. contents::
    :local:
.. currentmodule:: django_celery_monitor.models

.. automodule:: django_celery_monitor.models
    :members:
